@@ -17,7 +17,7 @@
 # Licence:: CC-BY-SA 2.0 or GPL-3+
 #
 
-VERSION = "5.5.2 (Grouping)"
+VERSION = "6.0 (Version Sync)"
 
 puts "CeWL #{VERSION} Robin Wood (robin@digi.ninja) (https://digi.ninja/)\n"
 
@@ -169,7 +169,9 @@ class MySpiderInstance<SpiderInstance
 
 				y = []
 				x.select do |a_url, parsed_url|
-					y << [a_url, parsed_url] if allowable_url?(a_url, parsed_url)
+                    if (parsed_url.scheme == "http" or parsed_url.scheme == "https") then
+                      y << [a_url, parsed_url] if allowable_url?(a_url, parsed_url)
+                    end
 				end
 
 				y.each do |a_url, parsed_url|
@@ -806,8 +808,9 @@ catch :ctrl_c do
 						end
 
 						puts "Found: #{a_url_parsed.path}" if @debug
-						if exclude_array.include?(a_url_parsed.path)
-							puts "Excluding path: #{a_url_parsed.path}" if verbose
+
+						if exclude_array.include?(a_url_parsed.request_uri)
+							puts "Excluding page: #{a_url_parsed.request_uri}" if verbose
 							allow = false
 						end
 
